@@ -48,6 +48,9 @@ test_that("diagram_mds is computing correctly",{
 
 test_that("diagram_mds can accept inputs from TDA, TDAstats and diagram_to_df",{
   
+  skip_if_not_installed("TDA")
+  skip_if_not_installed("TDAstats")
+  
   D1 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1)
   D2 = TDA::alphaComplexDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxdimension = 1)
   D3 = TDA::ripsDiag(data.frame(x = runif(50,0,1),y = runif(50,0,1)),maxscale = 1,maxdimension = 1,library = "dionysus",location = T)
