@@ -1,6 +1,8 @@
 
 test_that("diagram_to_df can accept the right kinds of input",{
   
+  skip_if_not_installed("TDA")
+  skip_if_not_installed("TDAstats")
   D <- TDA::circleUnif(n = 20,r = 1)
   phom_TDA <- TDA::ripsDiag(X = D,maxdimension = 1,maxscale = 2)
   phom_TDAstats <- TDAstats::calculate_homology(mat = D,threshold = 2)
